@@ -1,6 +1,6 @@
 package Net::GitHub::V3::Query;
 
-our $VERSION = '0.96';
+our $VERSION = '0.97';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI;
@@ -52,9 +52,9 @@ has 'alternate_url'   => ( is => 'rw', isa => Str );
 has 'RaiseError' => ( is => 'rw', isa => Bool, default => 1 );
 
 # Rate limits
-has 'rate_limit' => ( is => 'rw', isa => Int, default => 0 );
-has 'rate_limit_remaining' => ( is => 'rw', isa => Int, default => 0 );
-has 'rate_limit_reset' => ( is => 'rw', isa => Str, default => 0 );
+has 'rate_limit'           => ( is => 'rw', isa => Int, default => sub { shift->update_rate_limit('rate_limit') } );
+has 'rate_limit_remaining' => ( is => 'rw', isa => Int, default => sub { shift->update_rate_limit('rate_limit_remaining') } );
+has 'rate_limit_reset'     => ( is => 'rw', isa => Str, default => sub { shift->update_rate_limit('rate_limit_reset') } );
 
 # optional
 has 'u'  => (is => 'rw', isa => Str);
@@ -64,6 +64,18 @@ has 'repo' => (is => 'rw', isa => Str);
 has 'accept_version' => (is => 'rw', isa => Str, default => '');
 
 has 'is_main_module' => (is => 'ro', isa => Bool, default => 0);
+
+sub update_rate_limit {
+    my ( $self, $what ) = @_;
+
+    # If someone calls rate_limit before an API query happens, force these fields to update before giving back a response.
+    # Per github: Accessing this endpoint does not count against your REST API rate limit.
+    # https://developer.github.com/v3/rate_limit/
+    my $content = $self->query('/rate_limit');
+
+    return $self->{$what};
+}
+
 sub set_default_user_repo {
     my ($self, $user, $repo) = @_;
 
@@ -568,6 +580,10 @@ The number of requests remaining in the current rate limit window.
 
 The time the current rate limit resets in UTC epoch seconds.
 
+=item update_rate_limit
+
+Query the /rate_limit API (for free) to update the cached values for rate_limit, rate_limit_remaining, rate_limit_reset
+
 =item last_page
 
 Denotes the index of the last page in the pagination
